# Track feature-level metadata

So far, we haven't enabled ourselves to query for the _features_ of tracked datasets, and used LaminDB like a data lake.

Let us get on this! By that, we will impose some integrity on the data objects in our storage, and make them queryable.

Soon, we'll also see how this enables us to stream partial objects.

**Jump to:**

- {doc}`/guide/scrna`
- {doc}`/guide/flow`

```{toctree}
:hidden:
:maxdepth: 1

scrna
flow
```
